@@ -656,7 +656,8 @@ void add_line(WINDOW *window, int y, int x, line_t *line, int max_cols, int colo
     // IS_CODE
     if(CHECK_BIT(line->bits, IS_CODE)) {
 
-        if (!CHECK_BIT(line->bits, IS_TILDE_CODE)) {
+        if (!CHECK_BIT(line->bits, IS_TILDE_CODE) &&
+            !CHECK_BIT(line->bits, IS_GFM_CODE)) {
             // set static offset for code
             offset = CODE_INDENT;
         }
